HotspotConnectionPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • HotspotConnectionPlatform
Implementers

Constructors

HotspotConnectionPlatform()

Properties

discoveryEvents Stream<Peer>
no setter
hashCode int
The hash code for this object.
no setterinherited
roomEvents Stream<RoomEvent>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRoom(List<String> deviceIds) Future<RoomResult>
getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(String message) Future<void>
startBroadcasting(String username, String peerId) Future<void>
startDiscovery() Future<void>
stopDiscovery() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance HotspotConnectionPlatform
getter/setter pair