MethodChannelHotspotConnection class

Inheritance

Properties

discoveryEventChannel EventChannel
final
discoveryEvents Stream<Peer>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
roomEventChannel EventChannel
final
roomEvents Stream<RoomEvent>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRoom(List<String> deviceIds) Future<RoomResult>
override
getPlatformVersion() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(String message) Future<void>
override
startBroadcasting(String username, String peerId) Future<void>
override
startDiscovery() Future<void>
override
stopDiscovery() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited