MethodChannelHotspotConnection class
An implementation of HotspotConnectionPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- HotspotConnectionPlatform
- MethodChannelHotspotConnection
Constructors
Properties
- discoveryEventChannel → EventChannel
-
The event channel for discovery events.
final
-
discoveryEvents
→ Stream<
String> -
Stream of discovered devices. Contains the username or device ID.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- roomEventChannel → EventChannel
-
The event channel for room events.
final
-
roomEvents
→ Stream<
Map< String, dynamic> > -
Stream of incoming room messages and status changes.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createRoom(
List< String> deviceIds) → Future<void> -
Host creates a room with the selected device identifiers (e.g., usernames or network IPs).
override
-
getPlatformVersion(
) → Future< String?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(
String message) → Future< void> -
Send a message to the room.
override
-
startBroadcasting(
String username) → Future< void> -
Starts broadcasting the user's presence on the network.
override
-
startDiscovery(
) → Future< void> -
Starts discovering other broadcasting devices.
override
-
stopDiscovery(
) → Future< void> -
Stops discovering devices.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited