HotspotConnectionPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • HotspotConnectionPlatform
Implementers

Constructors

HotspotConnectionPlatform()
Constructs a HotspotConnectionPlatform.

Properties

discoveryEvents Stream<String>
Stream of discovered devices. Contains the username or device ID.
no setter
hashCode int
The hash code for this object.
no setterinherited
roomEvents Stream<Map<String, dynamic>>
Stream of incoming room messages and status changes.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRoom(List<String> deviceIds) Future<void>
Host creates a room with the selected device identifiers (e.g., usernames or network IPs).
getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(String message) Future<void>
Send a message to the room.
startBroadcasting(String username) Future<void>
Starts broadcasting the user's presence on the network.
startDiscovery() Future<void>
Starts discovering other broadcasting devices.
stopDiscovery() Future<void>
Stops discovering devices.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance HotspotConnectionPlatform
The default instance of HotspotConnectionPlatform to use.
getter/setter pair